calculateConstantCVGenDirichletK: Calculate Generalized Dirichlet parameters such that the...

Description Usage Arguments Value Examples

View source: R/genDirichlet.r

Description

Calculate Generalized Dirichlet parameters such that the margins have constant Coefficient of Variation

Usage

1

Arguments

p

probabilities

most.likely.k

The k of the most likely branch or dirichlet marginal

Value

the k vector such that all margins have a constant coefficient of variation

Examples

1

bertcarnell/dirichlet documentation built on May 12, 2021, 11:55 p.m.