qMarginalDirichlet: Quantiles of the marginal beta distributions in a dirichlet...

Description Usage Arguments Value Examples

View source: R/dirichlet.r

Description

Quantiles of the marginal beta distributions in a dirichlet distribution

Usage

1

Arguments

p

the probability of the desired quantile

alpha

the vector of dirichlet parameters

Value

the vector of marginal quantiles

Examples

1
qMarginalDirichlet(c(0.1, 0.2, 0.4), c(2,3,4))

bertcarnell/dirichlet documentation built on May 12, 2021, 11:55 p.m.