qdirichlet: Approxminate Dirichlet Quantiles

Description Usage Arguments Value Examples

View source: R/dirichlet.r

Description

qdirichlet is not an exact quantile function since the quantile of a multivariate distribtion is not unique. qdirichlet is also not the quantiles of the marginal distributions since those quantiles do not sum to one qdirichlet is the quantile of the underlying gamma functions, normalized This has been tested to show that qdirichlet approximates the dirichlet distribution well and creates the correct marginal means and variances when using a latin hypercube sample

Usage

1
qdirichlet(X, alpha)

Arguments

X

a matrix of marginal probabilities

alpha

The Dirichlet parameters. alpha > 0

Value

approximate dirichlet quantiles

Examples

1
qdirichlet(matrix(c(0.1, 0.1, 0.3), nrow=1, byrow=TRUE), c(2,3,4))

bertcarnell/dirichlet documentation built on May 12, 2021, 11:55 p.m.