Description Usage Arguments Value Examples
Calculate Generalized Dirichlet parameters such that the margins have constant Coefficient of Variation
1 | calculateConstantCVGenDirichletK(p, most.likely.k)
|
p |
probabilities |
most.likely.k |
The k of the most likely branch or dirichlet marginal |
the k vector such that all margins have a constant coefficient of variation
1 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.