Description Usage Arguments Value Examples
Random deviates of the Generalized Dirichlet distribution.
1 2 3 4 5 6 7 | dGenDirichlet(x, p, k)
dGenDirichletStd(x, a, b)
rGenDirichlet(n, p, k)
qGenDirichlet(X, p, k)
|
x |
number of observations. If length(n) > 1, the length is taken to be the number required. |
p, k |
The Generalized Dirichlet normalized parameters. The Dirichlet parameters may contain zeros if the branch to which a parameter is referring is not allowed. k * p = alpha |
a, b |
The Generalized Dirichlet standard parameters |
n |
the number of samples |
X |
a matrix of quantiles |
rGenDirichlet generates random deviates and dGenDirichlet generates densities
1 | rGenDirichlet(10, c(4,3,2)/9, c(2, 2, 2))
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.